@@ -7,7 +7,7 @@ use Carp;
 use Moo;
 use namespace::clean;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 with qw( CLDR::Number::Role::Format );
 
@@ -39,7 +39,7 @@ CLDR::Number::Format::Decimal - Localized decimal formatter using the Unicode CL
 
 =head1 VERSION
 
-This document describes CLDR::Number::Format::Decimal v0.16, built with Unicode
+This document describes CLDR::Number::Format::Decimal v0.17, built with Unicode
 CLDR v28.
 
 =head1 SYNOPSIS
@@ -54,7 +54,7 @@ CLDR v28.
     $decf = $cldr->decimal_formatter;
 
     # when locale is 'es' (Spanish)
-    say $decf->format(1234.5);  # '1.234,5'
+    say $decf->format(1234.5);  # '1234,5'
 
     # when locale is 'es-MX' (Mexican Spanish)
     say $decf->format(1234.5);  # '1,234.5'
@@ -173,7 +173,7 @@ L<code.shutterstock.com|http://code.shutterstock.com/>.
 
 =head1 COPYRIGHT AND LICENSE
 
-© 2013–2015 Shutterstock, Inc.
+© 2013–2016 Shutterstock, Inc.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
